#include "include/robot.h"

#include <pico/stdlib.h>
#include <time.h>
#include "include/i2c_master.h"
#include "include/udp_client.h"
#include "include/wifi_operator.h"

//#include "include/udp_fake_client.h"

int robot_init(void)
{
    stdio_init_all();

    udp_client_init();
    wifi_operator_init();

    i2c_master_init();
    if(init_gyro()) return -1;
    gyro_calibrate();

    robot.is_running = true;

    return 0;
}

static inline void update_time(void)
{
    static clock_t last_clock_state = 0;
    clock_t start_clock_state = clock();
    robot.delta_time_ms = (double)(start_clock_state - last_clock_state) * 1000.0 / CLOCKS_PER_SEC;
    last_clock_state = start_clock_state;
}

void robot_handle_inputs_outputs(void)
{
    //update_udp_buffer(); // Manualy control the robot

    update_time();

    gyro_update();

    i2c_update_motion_control();
}

void robot_deinit(void)
{
    udp_client_exit();
    i2c_master_deinit();
}